@@ -2,8 +2,9 @@
 
 """
 This module implements the main Custodian class, which manages a list of jobs
-given a set of error handlers, and the abstract base classes for the
-ErrorHandlers and Jobs.
+given a set of error handlers, the abstract base classes for the
+ErrorHandlers and Jobs, and some helper functions for backing up or
+compressing files in a directory.
 """
 
 from __future__ import division
@@ -12,14 +13,18 @@ __author__ = "Shyue Ping Ong, William Davidson Richards"
 __copyright__ = "Copyright 2012, The Materials Project"
 __version__ = "0.1"
 __maintainer__ = "Shyue Ping Ong"
-__email__ = "shyue@mit.edu"
+__email__ = "shyuep@gmail.com"
 __date__ = "May 3, 2013"
 
 import logging
 import subprocess
 import time
-from abc import ABCMeta, abstractmethod, abstractproperty
 import json
+import glob
+import tarfile
+import os
+from abc import ABCMeta, abstractmethod, abstractproperty
+
 
 
 class Custodian(object):
@@ -334,3 +339,43 @@ class Job(object):
         object given by the to_dict property.
         """
         pass
+
+
+def backup(filenames, prefix="error"):
+    """
+    Backup files to a tar.gz file. Used, for example, in backing up the
+    files of an errored run before performing corrections.
+
+    Args:
+        filenames:
+            List of files to backup. Supports wildcards, e.g., *.*.
+        prefix:
+            prefix to the files. Defaults to error, which means a series of
+            error.1.tar.gz, error.2.tar.gz, ... will be generated.
+    """
+    num = max([0] + [int(f.split(".")[1])
+                     for f in glob.glob("{}.*.tar.gz".format(prefix))])
+    filename = "{}.{}.tar.gz".format(prefix, num + 1)
+    logging.info("Backing up run to {}.".format(filename))
+    tar = tarfile.open(filename, "w:gz")
+    for fname in filenames:
+        for f in glob.glob(fname):
+            tar.add(f)
+    tar.close()
+
+
+def gzip_dir(path):
+    """
+    Gzips all files in a directory. Used, for instance, to compress all
+    files at the end of a run.
+
+    Args:
+        path:
+            Path to directory.
+    """
+    for f in os.listdir(path):
+        if not f.endswith("gz"):
+            with zopen(f, 'rb') as f_in, \
+                    zopen('{}.gz'.format(f), 'wb') as f_out:
+                f_out.writelines(f_in)
+            os.remove(f)
\ No newline at end of file
